==> create-tw-app-0.0.8.tgz: package/README.md <==
# Create thirdweb App

The easiest way to get started with thirdweb is by using `create-tw-app`. This CLI tool enables you to quickly start building a new thirdweb application, with everything set up for you. You can create a new app using one the defaults thirdweb templates, or by using one of the [official thirdweb examples](https://github.com/thirdweb-example). To get started, use the following command:

```bash
npx create-tw-app@latest
# or
yarn create tw-app
# or
pnpm create tw-app
```

This will prompt you to choose between "Next.js", "Create React App" and "Vite". You can also pass them as a flag:

```bash
npx create-tw-app --next
# or
npx create-tw-app --cra
# or
npx create-tw-app --vite
```

This will also prompt you to choose between TypeScript or JavaScript, you can also pass them as a flag:

```bash
npx create-tw-app --typescript
# or
npx create-tw-app --javascript
```

You can also use the shortcute `--js` or `--ts`.

An example of using both flags at the same time:

```bash
npx create-tw-app --next --ts`
```

To create a new app in a specific folder, you can send a name as an argument. For example, the following command will create a new Next.js app called `thirdwebb-app` in a folder with the same name:

```bash
npx create-tw-app@latest thirdweb-app
# or
yarn create tw-app thirdweb-app
# or
pnpm create tw-app thirdweb-app
```

One example of using the `--example` flag:

```bash
npx create-tw-app@latest --example custom-minting-page
# or
yarn create tw-app --example custom-minting-page
# or
pnpm create tw-app --example custom-minting-page
```

## Options

`create-tw-app` comes with the following options:

- **--ts, --typescript** - Initialize as a TypeScript project.
- **-e, --example [name]|[github-url]** - An example to bootstrap the app with. You can use an example name from the [thirdweb-example organization](https://github.com/thirdweb-example).
- **--use-npm** - Explicitly tell the CLI to bootstrap the app using npm. To bootstrap using yarn we recommend to run `yarn create tw-app`
- **--use-pnpm** - Explicitly tell the CLI to bootstrap the app using pnpm. To bootstrap using pnpm we recommend running `pnpm create tw-app`

## Why use Create thirdweb App?

`create-tw-app` allows you to create a new thirdweb app within seconds. It is officially maintained by the creators of thirdweb, and includes a number of benefits:

- **Interactive Experience**: Running `npx create-tw-app` (with no arguments) launches an interactive experience that guides you through setting up a project.
- **Zero Dependencies**: Initializing a project is as quick as one second. Create thirdweb App has zero dependencies.
- **Support for Examples**: Create thirdweb App can bootstrap your application using an example from the thirdweb examples collection (e.g. `npx create-tw-app --example contract-hub`).

==> create-tw-app-0.0.11.tgz: package/README.md <==
# Create thirdweb app

The easiest way to get started with thirdweb is by using `create-tw-app`. This CLI tool enables you to quickly start building a new thirdweb application, with everything set up for you. You can create a new app using one the defaults thirdweb templates, or by using one of the [official thirdweb examples](https://github.com/thirdweb-example). To get started, use the following command:

```bash
npx create-tw-app@latest
# or
yarn create tw-app
# or
pnpm create tw-app
```

This will prompt you to choose between "Next.js", "Create React App" and "Vite". You can also pass them as a flag:

```bash
npx create-tw-app --next
# or
npx create-tw-app --cra
# or
npx create-tw-app --vite
```

This will also prompt you to choose between TypeScript or JavaScript, you can also pass them as a flag:

```bash
npx create-tw-app --typescript
# or
npx create-tw-app --javascript
```

You can also use the shortcute `--js` or `--ts`.

An example of using both flags at the same time:

```bash
npx create-tw-app --next --ts`
```

To create a new app in a specific folder, you can send a name as an argument. For example, the following command will create a new Next.js app called `thirdwebb-app` in a folder with the same name:

```bash
npx create-tw-app@latest tw-app
# or
yarn create tw-app tw-app
# or
pnpm create tw-app tw-app
```

One example of using the `--example` flag:

```bash
npx create-tw-app@latest --example custom-minting-page
# or
yarn create tw-app --example custom-minting-page
# or
pnpm create tw-app --example custom-minting-page
```

## Options

`create-tw-app` comes with the following options:

- **--ts, --typescript** - Initialize as a TypeScript project.
- **-e, --example [name]|[github-url]** - An example to bootstrap the app with. You can use an example name from the [thirdweb-example organization](https://github.com/thirdweb-example).
- **--use-npm** - Explicitly tell the CLI to bootstrap the app using npm. To bootstrap using yarn we recommend to run `yarn create tw-app`
- **--use-pnpm** - Explicitly tell the CLI to bootstrap the app using pnpm. To bootstrap using pnpm we recommend running `pnpm create tw-app`

## Why use Create thirdweb App?

`create-tw-app` allows you to create a new thirdweb app within seconds. It is officially maintained by the creators of thirdweb, and includes a number of benefits:

- **Interactive Experience**: Running `npx create-tw-app` (with no arguments) launches an interactive experience that guides you through setting up a project.
- **Zero Dependencies**: Initializing a project is as quick as one second. Create thirdweb app has zero dependencies.
- **Support for Examples**: Create thirdweb app can bootstrap your application using an example from the thirdweb examples collection (e.g. `npx create-tw-app --example contract-hub`).

## Local Development
The simplest way to work on the CLI locally is to:

1. Install the package locally
2. Run the dev command to compile any changes in realtime
```bash
npm install -g ./
yarn dev
```
